Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1940)

Unified Diff: pkg/intl/tool/generate_locale_data_files.dart

Issue 341793004: Update Intl date and number formatting to CLDR 25. (Closed) Base URL: https://dart.googlecode.com/svn/branches/bleeding_edge/dart
Patch Set: Fixes Created 6 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « pkg/intl/test/number_test_data.dart ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: pkg/intl/tool/generate_locale_data_files.dart
diff --git a/pkg/intl/tool/generate_locale_data_files.dart b/pkg/intl/tool/generate_locale_data_files.dart
index f60f515736a8c6b13dd00a6a11d8653de5ab79c8..c0fbee37d97360d3f7ffc45cfc062fba180d63ee 100644
--- a/pkg/intl/tool/generate_locale_data_files.dart
+++ b/pkg/intl/tool/generate_locale_data_files.dart
@@ -8,7 +8,7 @@
* This should be run any time the locale data changes.
*
* The files are written under "data/dates", in two subdirectories, "symbols"
* and "patterns". In "data/dates" it will also generate "localeList.dart",
* which is sourced by the date_symbol_data... files.
*/
@@ -28,14 +28,13 @@ main() {
}
void writeLocaleList() {
- var file = new File(path.join(dataDirectory, 'localeList.dart'));
+ var file = new File(path.join(dataDirectory, 'locale_list.dart'));
var output = file.openWrite();
output.write(
'// Copyright (c) 2012, the Dart project authors. Please see the '
'AUTHORS file\n// for details. All rights reserved. Use of this source'
'code is governed by a\n// BSD-style license that can be found in the'
' LICENSE file.\n\n'
- 'part of date_symbol_data_json;\n\n'
'/// Hard-coded list of all available locales for dates.\n');
output.write('final availableLocalesForDateFormatting = const [');
List<String> allLocales = DateFormat.allLocalesWithSymbols();
@@ -8,7 +8,7 @@
*
* The files are written under "data/dates", in two subdirectories, "symbols"
- * and "patterns". In "data/dates" it will also generate "localeList.dart",
+ * and "patterns". In "data/dates" it will also generate "locale_list.dart",
* which is sourced by the date_symbol_data... files.
*/
« no previous file with comments | « pkg/intl/test/number_test_data.dart ('k') | no next file » | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698